#[non_exhaustive]pub struct AssessmentTaskDetails {
pub input_path: String,
pub output_dataset: String,
pub querylogs_path: String,
pub data_source: String,
pub feature_handle: Option<AssessmentFeatureHandle>,
/* private fields */
}Expand description
Assessment task config.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input_path: StringRequired. The Cloud Storage path for assessment input files.
output_dataset: StringRequired. The BigQuery dataset for output.
querylogs_path: StringOptional. An optional Cloud Storage path to write the query logs (which is then used as an input path on the translation task)
data_source: StringRequired. The data source or data warehouse type (eg: TERADATA/REDSHIFT) from which the input data is extracted.
feature_handle: Option<AssessmentFeatureHandle>Optional. A collection of additional feature flags for this assessment.
Implementations
Sourceimpl AssessmentTaskDetails
impl AssessmentTaskDetails
Sourcepub fn set_input_path<T: Into<String>>(self, v: T) -> Self
pub fn set_input_path<T: Into<String>>(self, v: T) -> Self
Sets the value of input_path.
Example
ⓘ
let x = AssessmentTaskDetails::new().set_input_path("example");Sourcepub fn set_output_dataset<T: Into<String>>(self, v: T) -> Self
pub fn set_output_dataset<T: Into<String>>(self, v: T) -> Self
Sets the value of output_dataset.
Example
ⓘ
let x = AssessmentTaskDetails::new().set_output_dataset("example");Sourcepub fn set_querylogs_path<T: Into<String>>(self, v: T) -> Self
pub fn set_querylogs_path<T: Into<String>>(self, v: T) -> Self
Sets the value of querylogs_path.
Example
ⓘ
let x = AssessmentTaskDetails::new().set_querylogs_path("example");Sourcepub fn set_data_source<T: Into<String>>(self, v: T) -> Self
pub fn set_data_source<T: Into<String>>(self, v: T) -> Self
Sets the value of data_source.
Example
ⓘ
let x = AssessmentTaskDetails::new().set_data_source("example");Sourcepub fn set_feature_handle<T>(self, v: T) -> Selfwhere
T: Into<AssessmentFeatureHandle>,
pub fn set_feature_handle<T>(self, v: T) -> Selfwhere
T: Into<AssessmentFeatureHandle>,
Sets the value of feature_handle.
Example
ⓘ
use google_cloud_bigquery_migration_v2::model::AssessmentFeatureHandle;
let x = AssessmentTaskDetails::new().set_feature_handle(AssessmentFeatureHandle::default()/* use setters */);Sourcepub fn set_or_clear_feature_handle<T>(self, v: Option<T>) -> Selfwhere
T: Into<AssessmentFeatureHandle>,
pub fn set_or_clear_feature_handle<T>(self, v: Option<T>) -> Selfwhere
T: Into<AssessmentFeatureHandle>,
Sets or clears the value of feature_handle.
Example
ⓘ
use google_cloud_bigquery_migration_v2::model::AssessmentFeatureHandle;
let x = AssessmentTaskDetails::new().set_or_clear_feature_handle(Some(AssessmentFeatureHandle::default()/* use setters */));
let x = AssessmentTaskDetails::new().set_or_clear_feature_handle(None::<AssessmentFeatureHandle>);Trait Implementations
Sourceimpl Clone for AssessmentTaskDetails
impl Clone for AssessmentTaskDetails
Sourcefn clone(&self) -> AssessmentTaskDetails
fn clone(&self) -> AssessmentTaskDetails
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssessmentTaskDetails
impl Debug for AssessmentTaskDetails
Sourceimpl Default for AssessmentTaskDetails
impl Default for AssessmentTaskDetails
Sourcefn default() -> AssessmentTaskDetails
fn default() -> AssessmentTaskDetails
Returns the “default value” for a type. Read more
Sourceimpl Message for AssessmentTaskDetails
impl Message for AssessmentTaskDetails
Sourceimpl PartialEq for AssessmentTaskDetails
impl PartialEq for AssessmentTaskDetails
impl StructuralPartialEq for AssessmentTaskDetails