#[non_exhaustive]pub struct SuggestionConfig {
pub skip_suggestion_steps: Vec<SuggestionStep>,
/* private fields */
}Expand description
The configuration for the suggestion if requested as a target type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.skip_suggestion_steps: Vec<SuggestionStep>The list of suggestion steps to skip.
Implementations
Sourceimpl SuggestionConfig
impl SuggestionConfig
Sourcepub fn set_skip_suggestion_steps<T, V>(self, v: T) -> Self
pub fn set_skip_suggestion_steps<T, V>(self, v: T) -> Self
Sets the value of skip_suggestion_steps.
Example
ⓘ
use google_cloud_bigquery_migration_v2::model::SuggestionStep;
let x = SuggestionConfig::new()
.set_skip_suggestion_steps([
SuggestionStep::default()/* use setters */,
SuggestionStep::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for SuggestionConfig
impl Clone for SuggestionConfig
Sourcefn clone(&self) -> SuggestionConfig
fn clone(&self) -> SuggestionConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SuggestionConfig
impl Debug for SuggestionConfig
Sourceimpl Default for SuggestionConfig
impl Default for SuggestionConfig
Sourcefn default() -> SuggestionConfig
fn default() -> SuggestionConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for SuggestionConfig
impl Message for SuggestionConfig
Sourceimpl PartialEq for SuggestionConfig
impl PartialEq for SuggestionConfig
Sourcefn eq(&self, other: &SuggestionConfig) -> bool
fn eq(&self, other: &SuggestionConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SuggestionConfig