#[non_exhaustive]pub struct TranslationReportRecord {
pub severity: Severity,
pub script_line: i32,
pub script_column: i32,
pub category: String,
pub message: String,
/* private fields */
}Expand description
Details about a record.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.severity: SeveritySeverity of the translation record.
script_line: i32Specifies the row from the source text where the error occurred (0 based). Example: 2
script_column: i32Specifies the column from the source texts where the error occurred. (0 based) example: 6
category: StringCategory of the error/warning. Example: SyntaxError
message: StringDetailed message of the record.
Implementations
Sourceimpl TranslationReportRecord
impl TranslationReportRecord
pub fn new() -> Self
Sourcepub fn set_severity<T: Into<Severity>>(self, v: T) -> Self
pub fn set_severity<T: Into<Severity>>(self, v: T) -> Self
Sets the value of severity.
Example
ⓘ
use google_cloud_bigquery_migration_v2::model::translation_report_record::Severity;
let x0 = TranslationReportRecord::new().set_severity(Severity::Info);
let x1 = TranslationReportRecord::new().set_severity(Severity::Warning);
let x2 = TranslationReportRecord::new().set_severity(Severity::Error);Sourcepub fn set_script_line<T: Into<i32>>(self, v: T) -> Self
pub fn set_script_line<T: Into<i32>>(self, v: T) -> Self
Sets the value of script_line.
Example
ⓘ
let x = TranslationReportRecord::new().set_script_line(42);Sourcepub fn set_script_column<T: Into<i32>>(self, v: T) -> Self
pub fn set_script_column<T: Into<i32>>(self, v: T) -> Self
Sets the value of script_column.
Example
ⓘ
let x = TranslationReportRecord::new().set_script_column(42);Sourcepub fn set_category<T: Into<String>>(self, v: T) -> Self
pub fn set_category<T: Into<String>>(self, v: T) -> Self